@@ -191,9 +191,9 @@ write_part_bodystructure (GMimeObject *part, FILE *fp)
 		/* print body */
 		write_part_bodystructure ((GMimeObject *) message->mime_part, fp);
 	} else if (GMIME_IS_PART (part)) {
-		if (GMIME_PART (part)->disposition) {
-			fprintf (fp, "\"%s\" ", GMIME_PART (part)->disposition->disposition);
-			if ((param = GMIME_PART (part)->disposition->params)) {
+		if (GMIME_OBJECT (part)->disposition) {
+			fprintf (fp, "\"%s\" ", GMIME_OBJECT (part)->disposition->disposition);
+			if ((param = GMIME_OBJECT (part)->disposition->params)) {
 				fputc ('(', fp);
 				while (param) {
 					fprintf (fp, "\"%s\" \"%s\"", param->name, param->value);
@@ -209,22 +209,22 @@ write_part_bodystructure (GMimeObject *part, FILE *fp)
 		}
 		
 		switch (GMIME_PART (part)->encoding) {
-		case GMIME_PART_ENCODING_7BIT:
+		case GMIME_CONTENT_ENCODING_7BIT:
 			fputs ("\"7bit\"", fp);
 			break;
-		case GMIME_PART_ENCODING_8BIT:
+		case GMIME_CONTENT_ENCODING_8BIT:
 			fputs ("\"8bit\"", fp);
 			break;
-		case GMIME_PART_ENCODING_BINARY:
+		case GMIME_CONTENT_ENCODING_BINARY:
 			fputs ("\"binary\"", fp);
 			break;
-		case GMIME_PART_ENCODING_BASE64:
+		case GMIME_CONTENT_ENCODING_BASE64:
 			fputs ("\"base64\"", fp);
 			break;
-		case GMIME_PART_ENCODING_QUOTEDPRINTABLE:
+		case GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE:
 			fputs ("\"quoted-printable\"", fp);
 			break;
-		case GMIME_PART_ENCODING_UUENCODE:
+		case GMIME_CONTENT_ENCODING_UUENCODE:
 			fputs ("\"x-uuencode\"", fp);
 			break;
 		default:
