@@ -142,7 +142,7 @@ cipher_hash_id (GMimeCipherContext *ctx, const char *hash)
 
 
 /**
- * g_mime_cipher_hash_id:
+ * g_mime_cipher_context_hash_id:
  * @ctx: Cipher Context
  * @hash: hash name
  *
@@ -151,7 +151,7 @@ cipher_hash_id (GMimeCipherContext *ctx, const char *hash)
  * Returns the equivalent hash id or #GMIME_CIPHER_HASH_DEFAULT on fail.
  **/
 GMimeCipherHash
-g_mime_cipher_hash_id (GMimeCipherContext *ctx, const char *hash)
+g_mime_cipher_context_hash_id (GMimeCipherContext *ctx, const char *hash)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), GMIME_CIPHER_HASH_DEFAULT);
 	g_return_val_if_fail (hash != NULL, GMIME_CIPHER_HASH_DEFAULT);
@@ -168,7 +168,7 @@ cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
 
 
 /**
- * g_mime_cipher_hash_name:
+ * g_mime_cipher_context_hash_name:
  * @ctx: Cipher Context
  * @hash: hash id
  *
@@ -177,7 +177,7 @@ cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
  * Returns the equivalent hash name or %NULL on fail.
  **/
 const char *
-g_mime_cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
+g_mime_cipher_context_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), NULL);
 	
@@ -197,7 +197,7 @@ cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
 
 
 /**
- * g_mime_cipher_sign:
+ * g_mime_cipher_context_sign:
  * @ctx: Cipher Context
  * @userid: private key to use to sign the stream
  * @hash: preferred Message-Integrity-Check hash algorithm
@@ -210,8 +210,8 @@ cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
  * Returns %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
-		    GMimeStream *istream, GMimeStream *ostream, GError **err)
+g_mime_cipher_context_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
+			    GMimeStream *istream, GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -233,7 +233,7 @@ cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istre
 
 
 /**
- * g_mime_cipher_verify:
+ * g_mime_cipher_context_verify:
  * @ctx: Cipher Context
  * @hash: secure hash used
  * @istream: input stream
@@ -250,8 +250,8 @@ cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istre
  * execute at all.
  **/
 GMimeSignatureValidity *
-g_mime_cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istream,
-		      GMimeStream *sigstream, GError **err)
+g_mime_cipher_context_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istream,
+			      GMimeStream *sigstream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), NULL);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), NULL);
@@ -272,7 +272,7 @@ cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtr
 
 
 /**
- * g_mime_cipher_encrypt:
+ * g_mime_cipher_context_encrypt:
  * @ctx: Cipher Context
  * @sign: sign as well as encrypt
  * @userid: key id (or email address) to use when signing (assuming @sign is %TRUE)
@@ -287,8 +287,8 @@ cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtr
  * Returns %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtrArray *recipients,
-		       GMimeStream *istream, GMimeStream *ostream, GError **err)
+g_mime_cipher_context_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtrArray *recipients,
+			       GMimeStream *istream, GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -310,7 +310,7 @@ cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
 
 
 /**
- * g_mime_cipher_decrypt:
+ * g_mime_cipher_context_decrypt:
  * @ctx: Cipher Context
  * @istream: input/ciphertext stream
  * @ostream: output/cleartext stream
@@ -322,8 +322,8 @@ cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
  * Returns %0 on success or %-1 for fail.
  **/
 int
-g_mime_cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
-		       GMimeStream *ostream, GError **err)
+g_mime_cipher_context_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
+			       GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -344,7 +344,7 @@ cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
 
 
 /**
- * g_mime_cipher_import_keys:
+ * g_mime_cipher_context_import_keys:
  * @ctx: Cipher Context
  * @istream: input stream (containing keys)
  * @err: exception
@@ -355,7 +355,7 @@ cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
  * Returns %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
+g_mime_cipher_context_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -376,7 +376,7 @@ cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
 
 
 /**
- * g_mime_cipher_export_keys:
+ * g_mime_cipher_context_export_keys:
  * @ctx: Cipher Context
  * @keys: an array of key ids
  * @ostream: output stream
@@ -388,8 +388,8 @@ cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
  * Returns %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
-			   GMimeStream *ostream, GError **err)
+g_mime_cipher_context_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
+				   GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (ostream), -1);
@@ -604,164 +604,3 @@ g_mime_signature_validity_add_signer  (GMimeSignatureValidity *validity, GMimeSi
 		s->next = signer;
 	}
 }
-
-
-
-
-
-/**
- * g_mime_cipher_validity_new:
- *
- * Creates a new validity structure.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_new() instead.
- *
- * Returns a new #GMimeCipherValidity.
- **/
-GMimeCipherValidity *
-g_mime_cipher_validity_new (void)
-{
-	return g_mime_signature_validity_new ();
-}
-
-
-/**
- * g_mime_cipher_validity_init:
- * @validity: validity structure
- *
- * Initializes the validity structure.
- *
- * WARNING: This interface has been deprecated.
- **/ 
-void
-g_mime_cipher_validity_init (GMimeCipherValidity *validity)
-{
-	g_assert (validity != NULL);
-	
-	validity->status = GMIME_SIGNATURE_STATUS_NONE;
-	validity->details = NULL;
-	validity->signers = NULL;
-}
-
-
-/**
- * g_mime_cipher_validity_get_valid:
- * @validity: validity structure
- *
- * Gets the validity of the validity structure @validity.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_get_status() instead.
- *
- * Returns %TRUE if @validity is valid or %FALSE otherwise.
- **/
-gboolean
-g_mime_cipher_validity_get_valid (GMimeCipherValidity *validity)
-{
-	if (validity == NULL)
-		return FALSE;
-	
-	return validity->status == GMIME_SIGNATURE_STATUS_GOOD;
-}
-
-
-/**
- * g_mime_cipher_validity_set_valid:
- * @validity: validity structure
- * @valid: %TRUE if valid else %FALSE
- *
- * Sets the validness on the validity structure.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_set_status() instead.
- **/
-void
-g_mime_cipher_validity_set_valid (GMimeCipherValidity *validity, gboolean valid)
-{
-	g_assert (validity != NULL);
-	
-	validity->status = valid ? GMIME_SIGNATURE_STATUS_GOOD : GMIME_SIGNATURE_STATUS_BAD;
-}
-
-
-/**
- * g_mime_cipher_validity_get_description:
- * @validity: validity structure
- *
- * Gets the description set on the validity structure @validity.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_get_details() instead.
- *
- * Returns any description set on the validity structure.
- **/
-const char *
-g_mime_cipher_validity_get_description (GMimeCipherValidity *validity)
-{
-	return g_mime_signature_validity_get_details (validity);
-}
-
-
-/**
- * g_mime_cipher_validity_set_description:
- * @validity: validity structure
- * @description: validity description
- *
- * Sets the description on the validity structure.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_set_details() instead.
- **/
-void
-g_mime_cipher_validity_set_description (GMimeCipherValidity *validity, const char *description)
-{
-	g_mime_signature_validity_set_details (validity, description);
-}
-
-
-/**
- * g_mime_cipher_validity_clear:
- * @validity: validity structure
- *
- * Clears the contents of the validity structure.
- *
- * WARNING: This interface has been deprecated.
- **/
-void
-g_mime_cipher_validity_clear (GMimeCipherValidity *validity)
-{
-	GMimeSigner *signer, *next;
-	
-	g_assert (validity != NULL);
-	
-	validity->status = GMIME_SIGNATURE_STATUS_NONE;
-	g_free (validity->details);
-	validity->details = NULL;
-	
-	signer = validity->signers;
-	while (signer != NULL) {
-		next = signer->next;
-		g_free (signer->fingerprint);
-		g_free (signer->keyid);
-		g_free (signer->name);
-		g_free (signer);
-		signer = next;
-	}
-}
-
-
-/**
- * g_mime_cipher_validity_free:
- * @validity: validity structure
- *
- * Frees the memory used by @validity back to the system.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_free() instead.
- **/
-void
-g_mime_cipher_validity_free (GMimeCipherValidity *validity)
-{
-	g_mime_signature_validity_free (validity);
-}
