@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -53,10 +53,14 @@
  **/
 
 
+struct _GMimeObject;
+void _g_mime_object_content_type_changed (struct _GMimeObject *object);
+
+
 /**
  * g_mime_content_type_new:
- * @type: MIME type (or NULL for "text")
- * @subtype: MIME subtype (or NULL for "plain")
+ * @type: MIME type (or %NULL for "text")
+ * @subtype: MIME subtype (or %NULL for "plain")
  *
  * Creates a Content-Type object with type @type and subtype @subtype.
  *
@@ -100,22 +104,20 @@ g_mime_content_type_new (const char *type, const char *subtype)
 
 /**
  * g_mime_content_type_new_from_string:
- * @string: input string containing a content-type (and params)
+ * @str: input string containing a content-type (and params)
  *
  * Constructs a new Content-Type object based on the input string.
  *
  * Returns a new MIME Content-Type based on the input string.
  **/
 GMimeContentType *
-g_mime_content_type_new_from_string (const char *string)
+g_mime_content_type_new_from_string (const char *str)
 {
 	GMimeContentType *mime_type;
 	char *type = NULL, *subtype;
-	const char *inptr;
+	const char *inptr = str;
 	
-	g_return_val_if_fail (string != NULL, NULL);
-	
-	inptr = string;
+	g_return_val_if_fail (str != NULL, NULL);
 	
 	/* get the type */
 	type = (char *) inptr;
@@ -255,6 +257,57 @@ g_mime_content_type_is_type (const GMimeContentType *mime_type, const char *type
 }
 
 
+/**
+ * g_mime_content_type_get_media_type:
+ * @mime_type: MIME Content-Type
+ *
+ * Gets the Content-Type's media type.
+ *
+ * Returns the Content-Type's media type.
+ **/
+const char *
+g_mime_content_type_get_media_type (const GMimeContentType *mime_type)
+{
+	g_return_val_if_fail (mime_type != NULL, NULL);
+	
+	return mime_type->type;
+}
+
+
+/**
+ * g_mime_content_type_get_media_subtype:
+ * @mime_type: MIME Content-Type
+ *
+ * Gets the Content-Type's media sub-type.
+ *
+ * Returns the Content-Type's media sub-type.
+ **/
+const char *
+g_mime_content_type_get_media_subtype (const GMimeContentType *mime_type)
+{
+	g_return_val_if_fail (mime_type != NULL, NULL);
+	
+	return mime_type->subtype;
+}
+
+
+/**
+ * g_mime_content_type_get_params:
+ * @mime_type: MIME Content-Type
+ *
+ * Gets the Content-Type's parameter list.
+ *
+ * Returns the Content-Type's parameter list.
+ **/
+const GMimeParam *
+g_mime_content_type_get_params (const GMimeContentType *mime_type)
+{
+	g_return_val_if_fail (mime_type != NULL, NULL);
+	
+	return mime_type->params;
+}
+
+
 /**
  * g_mime_content_type_set_parameter:
  * @mime_type: MIME Content-Type
@@ -276,18 +329,21 @@ g_mime_content_type_set_parameter (GMimeContentType *mime_type, const char *attr
 		if ((param = g_hash_table_lookup (mime_type->param_hash, attribute))) {
 			g_free (param->value);
 			param->value = g_strdup (value);
-			return;
+			goto changed;
 		}
 	} else if (!mime_type->param_hash) {
 		/* hash table not initialized */
 		mime_type->param_hash = g_hash_table_new (g_mime_strcase_hash, g_mime_strcase_equal);
 	}
 	
-	if (param == NULL) {
-		param = g_mime_param_new (attribute, value);
-		mime_type->params = g_mime_param_append_param (mime_type->params, param);
-		g_hash_table_insert (mime_type->param_hash, param->name, param);
-	}
+	param = g_mime_param_new (attribute, value);
+	mime_type->params = g_mime_param_append_param (mime_type->params, param);
+	g_hash_table_insert (mime_type->param_hash, param->name, param);
+	
+ changed:
+	
+	if (mime_type->parent_object)
+		_g_mime_object_content_type_changed (mime_type->parent_object);
 }
 
 
