@@ -58,7 +58,7 @@ static void message_remove_header (GMimeObject *object, const char *header);
 static char *message_get_headers (GMimeObject *object);
 static ssize_t message_write_to_stream (GMimeObject *object, GMimeStream *stream);
 
-static void message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string);
+static void message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str);
 
 static ssize_t write_structured (GMimeStream *stream, const char *name, const char *value);
 static ssize_t write_addrspec (GMimeStream *stream, const char *name, const char *value);
@@ -1014,7 +1014,7 @@ sync_recipient_header (GMimeMessage *message, const char *type)
  * #GMIME_RECIPIENT_TYPE_CC and #GMIME_RECIPIENT_TYPE_BCC.
  **/
 void
-g_mime_message_add_recipient (GMimeMessage *message, const char *type, const char *name, const char *address)
+g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address)
 {
 	InternetAddressList *recipients;
 	InternetAddress *ia;
@@ -1032,25 +1032,25 @@ g_mime_message_add_recipient (GMimeMessage *message, const char *type, const cha
 	recipients = internet_address_list_append (recipients, ia);
 	internet_address_unref (ia);
 	
-	g_hash_table_insert (message->recipients, (char *) type, recipients);
+	g_hash_table_insert (message->recipients, type, recipients);
 	sync_recipient_header (message, type);
 }
 
 
 static void
-message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string)
+message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str)
 {
 	InternetAddressList *recipients, *addrlist;
 	
 	recipients = g_hash_table_lookup (message->recipients, type);
 	g_hash_table_remove (message->recipients, type);
 	
-	if ((addrlist = internet_address_parse_string (string))) {
+	if ((addrlist = internet_address_parse_string (str))) {
 		recipients = internet_address_list_concat (recipients, addrlist);
 		internet_address_list_destroy (addrlist);
 	}
 	
-	g_hash_table_insert (message->recipients, (char *) type, recipients);
+	g_hash_table_insert (message->recipients, type, recipients);
 }
 
 
@@ -1058,7 +1058,7 @@ message_add_recipients_from_string (GMimeMessage *message, const char *type, con
  * g_mime_message_add_recipients_from_string:
  * @message: MIME Message
  * @type: Recipient type
- * @string: A string of recipient names and addresses.
+ * @str: A string of recipient names and addresses.
  *
  * Add a list of recipients of a chosen type to the MIME
  * Message. Available recipient types include:
@@ -1067,13 +1067,13 @@ message_add_recipients_from_string (GMimeMessage *message, const char *type, con
  * specified in rfc822.
  **/
 void
-g_mime_message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string)
+g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str)
 {
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
 	g_return_if_fail (type != NULL);
-	g_return_if_fail (string != NULL);
+	g_return_if_fail (str != NULL);
 	
-	message_add_recipients_from_string (message, type, string);
+	message_add_recipients_from_string (message, type, str);
 	
 	sync_recipient_header (message, type);
 }
@@ -1301,8 +1301,11 @@ g_mime_message_get_message_id (GMimeMessage *message)
  * @header: rfc822 header field
  * @value: the contents of the header field
  *
- * Add an arbitrary message header to the MIME Message such as X-Mailer,
- * X-Priority, or In-Reply-To.
+ * Add an arbitrary message header to the MIME Message such as
+ * X-Mailer, X-Priority, or In-Reply-To.
+ *
+ * WARNING: This interface is deprecated. Use
+ * g_mime_object_add_header() instead.
  **/
 void
 g_mime_message_add_header (GMimeMessage *message, const char *header, const char *value)
@@ -1321,8 +1324,11 @@ g_mime_message_add_header (GMimeMessage *message, const char *header, const char
  * @header: rfc822 header field
  * @value: the contents of the header field
  *
- * Set an arbitrary message header to the MIME Message such as X-Mailer,
- * X-Priority, or In-Reply-To.
+ * Set an arbitrary message header to the MIME Message such as
+ * X-Mailer, X-Priority, or In-Reply-To.
+ *
+ * WARNING: This interface is deprecated. Use
+ * g_mime_object_set_header().
  **/
 void
 g_mime_message_set_header (GMimeMessage *message, const char *header, const char *value)
@@ -1343,7 +1349,11 @@ g_mime_message_set_header (GMimeMessage *message, const char *header, const char
  * Gets the value of the requested header @header if it exists, or
  * %NULL otherwise.
  *
- * Returns the value of the requested header (or %NULL if it isn't set)
+ * WARNING: This interface is deprecated. Use
+ * g_mime_message_get_header().
+ *
+ * Returns the value of the requested header (or %NULL if it isn't
+ * set)
  **/
 const char *
 g_mime_message_get_header (GMimeMessage *message, const char *header)
@@ -1401,48 +1411,6 @@ g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part)
 }
 
 
-/**
- * g_mime_message_write_to_stream:
- * @message: MIME Message
- * @stream: output stream
- *
- * Write the contents of the MIME Message to @stream.
- *
- * WARNING: This interface is deprecated. Use
- * g_mime_object_write_to_stream() instead.
- *
- * Returns %-1 on fail.
- **/
-ssize_t
-g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream)
-{
-	g_return_val_if_fail (GMIME_IS_MESSAGE (message), -1);
-	g_return_val_if_fail (GMIME_IS_STREAM (stream), -1);
-	
-	return g_mime_object_write_to_stream ((GMimeObject *) message, stream);
-}
-
-
-/**
- * g_mime_message_to_string:
- * @message: MIME Message
- *
- * Allocates a string buffer containing the mime message @message.
- *
- * WARNING: This interface is deprecated. Use
- * g_mime_object_to_string() instead.
- *
- * Returns an allocated string containing the MIME Message.
- **/
-char *
-g_mime_message_to_string (GMimeMessage *message)
-{
-	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
-	
-	return g_mime_object_to_string ((GMimeObject *) message);
-}
-
-
 /* The proper way to handle a multipart/alternative part is to return
  * the last part that we know how to render. For our purposes, we are
  * going to assume:
@@ -1527,71 +1495,15 @@ handle_multipart_mixed (GMimeMultipart *multipart, gboolean want_plain, gboolean
 }
 
 
-/**
- * g_mime_message_get_body:
- * @message: MIME Message
- * @want_plain: request text/plain
- * @is_html: body returned is in html format
- *
- * Attempts to get the body of the message in the preferred format
- * specified by @want_plain.
- *
- * WARNING: This interface is deprecated.
- *
- * Returns the prefered form of the message body. Sets the value of
- * @is_html to %TRUE if the part returned is in HTML format, otherwise
- * %FALSE.
- *
- * Note: This function is NOT guarenteed to always work as it
- * makes some assumptions that are not necessarily true. It is
- * recommended that you traverse the MIME structure yourself.
- **/
-char *
-g_mime_message_get_body (const GMimeMessage *message, gboolean want_plain, gboolean *is_html)
-{
-	GMimeObject *mime_part = NULL;
-	const GMimeContentType *type;
-	GMimeMultipart *multipart;
-	const char *content;
-	char *body = NULL;
-	size_t len = 0;
-	
-	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
-	g_return_val_if_fail (is_html != NULL, NULL);
-	
-	type = g_mime_object_get_content_type (message->mime_part);
-	if (GMIME_IS_MULTIPART (message->mime_part)) {
-		/* let's see if we can find a body in the multipart */
-		multipart = GMIME_MULTIPART (message->mime_part);
-		if (g_mime_content_type_is_type (type, "multipart", "alternative"))
-			mime_part = handle_multipart_alternative (multipart, want_plain, is_html);
-		else
-			mime_part = handle_multipart_mixed (multipart, want_plain, is_html);
-	} else if (g_mime_content_type_is_type (type, "text", "*")) {
-		/* this *has* to be the message body */
-		if (g_mime_content_type_is_type (type, "text", "html"))
-			*is_html = TRUE;
-		else
-			*is_html = FALSE;
-		
-		mime_part = message->mime_part;
-	}
-	
-	if (mime_part != NULL) {
-		content = g_mime_part_get_content (GMIME_PART (mime_part), &len);
-		body = g_strndup (content, len);
-	}
-	
-	return body;
-}
-
-
 /**
  * g_mime_message_get_headers:
  * @message: MIME Message
  *
  * Allocates a string buffer containing the raw message headers.
  *
+ * WARNING: This interface is deprecated. Use
+ * g_mime_object_get_headers() instead.
+ *
  * Returns an allocated string containing the raw message headers.
  **/
 char *
