@@ -101,8 +101,8 @@ const char *g_mime_message_get_sender (GMimeMessage *message);
 void g_mime_message_set_reply_to (GMimeMessage *message, const char *reply_to);
 const char *g_mime_message_get_reply_to (GMimeMessage *message);
 
-void g_mime_message_add_recipient (GMimeMessage *message, const char *type, const char *name, const char *address);
-void g_mime_message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string);
+void g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address);
+void g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str);
 const InternetAddressList *g_mime_message_get_recipients (GMimeMessage *message, const char *type);
 InternetAddressList *g_mime_message_get_all_recipients (GMimeMessage *message);
 
@@ -123,13 +123,6 @@ const char *g_mime_message_get_header (GMimeMessage *message, const char *header
 GMimeObject *g_mime_message_get_mime_part (GMimeMessage *message);
 void g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part);
 
-#ifndef GMIME_DISABLE_DEPRECATED
-ssize_t g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream);
-char *g_mime_message_to_string (GMimeMessage *message);
-
-char *g_mime_message_get_body (const GMimeMessage *message, gboolean want_plain, gboolean *is_html);
-#endif /* GMIME_DISABLE_DEPRECATED */
-
 char *g_mime_message_get_headers (GMimeMessage *message);
 
 void g_mime_message_foreach_part (GMimeMessage *message, GMimePartFunc callback, gpointer data);
