@@ -87,7 +87,7 @@ enum {
 struct _GMimeParserPrivate {
 	GMimeStream *stream;
 	
-	off_t offset;
+	gint64 offset;
 	
 	/* i/o buffers */
 	char realbuf[SCAN_HEAD + SCAN_BUF + 1];
@@ -95,7 +95,7 @@ struct _GMimeParserPrivate {
 	char *inptr;
 	char *inend;
 	
-	off_t from_offset;
+	gint64 from_offset;
 	GByteArray *from_line;
 	
 	regex_t header_regex;
@@ -112,12 +112,8 @@ struct _GMimeParserPrivate {
 	char *rawptr;
 	size_t rawleft;
 	
-	/* current message headerblock offsets */
-	off_t headers_begin;
-	off_t headers_end;
-	
-	/* current header field offset */
-	off_t header_offset;
+	gint64 headers_start;
+	gint64 header_start;
 	
 	short int state;
 	
@@ -129,6 +125,7 @@ struct _GMimeParserPrivate {
 	unsigned short int persist_stream:1;
 	unsigned short int respect_content_length:1;
 	
+	GMimeContentType *content_type;
 	struct _header_raw *headers;
 	
 	struct _boundary_stack *bounds;
@@ -140,7 +137,7 @@ struct _boundary_stack {
 	size_t boundarylen;
 	size_t boundarylenfinal;
 	size_t boundarylenmax;
-	off_t content_end;
+	gint64 content_end;
 };
 
 
@@ -194,11 +191,11 @@ struct _header_raw {
 	struct _header_raw *next;
 	char *name;
 	char *value;
-	off_t offset;
+	gint64 offset;
 };
 
 static const char *
-header_raw_find (struct _header_raw *headers, const char *name, off_t *offset)
+header_raw_find (struct _header_raw *headers, const char *name, gint64 *offset)
 {
 	struct _header_raw *h;
 	
@@ -300,7 +297,7 @@ static void
 parser_init (GMimeParser *parser, GMimeStream *stream)
 {
 	struct _GMimeParserPrivate *priv = parser->priv;
-	off_t offset = -1;
+	gint64 offset = -1;
 	
 	if (stream) {
 		g_object_ref (stream);
@@ -328,10 +325,8 @@ parser_init (GMimeParser *parser, GMimeStream *stream)
 	priv->rawptr = priv->rawbuf;
 	priv->rawleft = SCAN_HEAD;
 	
-	priv->headers_begin = -1;
-	priv->headers_end = -1;
-	
-	priv->header_offset = -1;
+	priv->headers_start = -1;
+	priv->header_start = -1;
 	
 	priv->midline = FALSE;
 	priv->seekable = offset != -1;
@@ -632,7 +627,7 @@ parser_fill (GMimeParser *parser)
 }
 
 
-static off_t
+static gint64
 parser_offset (struct _GMimeParserPrivate *priv, const char *inptr)
 {
 	if (priv->offset == -1)
@@ -654,7 +649,7 @@ parser_offset (struct _GMimeParserPrivate *priv, const char *inptr)
  * Returns the current stream offset from the parser's internal stream
  * or -1 on error.
  **/
-off_t
+gint64
 g_mime_parser_tell (GMimeParser *parser)
 {
 	g_return_val_if_fail (GMIME_IS_PARSER (parser), -1);
@@ -746,31 +741,19 @@ parser_step_from (GMimeParser *parser)
 	return 0;
 }
 
-static inline size_t
-nearest_pow (size_t num)
-{
-	size_t n = num > 0 ? num - 1 : 0;
-	
-	n |= n >> 1;
-	n |= n >> 2;
-	n |= n >> 4;
-	n |= n >> 8;
-	n |= n >> 16;
-	n++;
-	
-	return n;
-}
-
 #define header_append(priv, start, len) G_STMT_START {                    \
 	if (priv->headerleft <= len) {                                    \
 		size_t hlen, hoff;                                        \
 		                                                          \
-		hoff = priv->headerptr - priv->headerbuf;                 \
-		hlen = nearest_pow (hoff + len + 1);                      \
+		hlen = hoff = priv->headerptr - priv->headerbuf;          \
+		hlen = hlen ? hlen : 1;                                   \
 		                                                          \
-		priv->headerbuf = g_realloc (priv->headerbuf, hlen);      \
+		while (hlen < hoff + len)                                 \
+			hlen <<= 1;                                       \
+		                                                          \
+		priv->headerbuf = g_realloc (priv->headerbuf, hlen + 1);  \
 		priv->headerptr = priv->headerbuf + hoff;                 \
-		priv->headerleft = (hlen - 1) - hoff;                     \
+		priv->headerleft = hlen - hoff;                           \
 	}                                                                 \
 	                                                                  \
 	memcpy (priv->headerptr, start, len);                             \
@@ -782,12 +765,15 @@ nearest_pow (size_t num)
 	if (priv->rawleft <= len) {                                       \
 		size_t hlen, hoff;                                        \
 		                                                          \
-		hoff = priv->rawptr - priv->rawbuf;                       \
-		hlen = nearest_pow (hoff + len + 1);                      \
+		hlen = hoff = priv->rawptr - priv->rawbuf;                \
+		hlen = hlen ? hlen : 1;                                   \
 		                                                          \
-		priv->rawbuf = g_realloc (priv->rawbuf, hlen);            \
+		while (hlen < hoff + len)                                 \
+			hlen <<= 1;                                       \
+		                                                          \
+		priv->rawbuf = g_realloc (priv->rawbuf, hlen + 1);        \
 		priv->rawptr = priv->rawbuf + hoff;                       \
-		priv->rawleft = (hlen - 1) - hoff;                        \
+		priv->rawleft = hlen - hoff;                              \
 	}                                                                 \
 	                                                                  \
 	memcpy (priv->rawptr, start, len);                                \
@@ -817,7 +803,7 @@ header_parse (GMimeParser *parser, struct _header_raw **tail)
 	if (*inptr != ':') {
 		/* ignore invalid headers */
 		w(g_warning ("Invalid header at %lld: '%s'",
-			     (long long) priv->header_offset,
+			     (long long) priv->header_start,
 			     priv->headerbuf));
 		
 		priv->headerleft += priv->headerptr - priv->headerbuf;
@@ -849,7 +835,7 @@ header_parse (GMimeParser *parser, struct _header_raw **tail)
 	
 	header->value = g_strndup (start, end - start);
 	
-	header->offset = priv->header_offset;
+	header->offset = priv->header_start;
 	
 	(*tail)->next = header;
 	*tail = header;
@@ -879,10 +865,8 @@ parser_step_headers (GMimeParser *parser)
 	raw_header_reset (priv);
 	header_raw_clear (&priv->headers);
 	hend = (struct _header_raw *) &priv->headers;
-	priv->header_offset = parser_offset (priv, NULL);
-	
-	if (priv->headers_begin == -1)
-		priv->headers_begin = parser_offset (priv, NULL);
+	priv->headers_start = parser_offset (priv, NULL);
+	priv->header_start = parser_offset (priv, NULL);
 	
 	inptr = priv->inptr;
 	inend = priv->inend;
@@ -905,7 +889,7 @@ parser_step_headers (GMimeParser *parser)
 			/* if we are scanning a new line, check for a folded header */
 			if (!priv->midline && continuation && (*inptr != ' ' && *inptr != '\t')) {
 				header_parse (parser, &hend);
-				priv->header_offset = parser_offset (priv, inptr);
+				priv->header_start = parser_offset (priv, inptr);
 				continuation = FALSE;
 				fieldname = TRUE;
 				valid = TRUE;
@@ -1013,9 +997,6 @@ parser_step_headers (GMimeParser *parser)
 	if (priv->headerptr > priv->headerbuf)
 		header_parse (parser, &hend);
 	
-	if (priv->headers_end == -1)
-		priv->headers_end = parser_offset (priv, start);
-	
 	priv->state = GMIME_PARSER_STATE_HEADERS_END;
 	*priv->rawptr = '\0';
 	priv->inptr = inptr;
@@ -1024,9 +1005,6 @@ parser_step_headers (GMimeParser *parser)
 	
  next_message:
 	
-	if (priv->headers_end == -1)
-		priv->headers_end = parser_offset (priv, start);
-	
 	priv->state = GMIME_PARSER_STATE_COMPLETE;
 	*priv->rawptr = '\0';
 	priv->inptr = start;
@@ -1035,9 +1013,6 @@ parser_step_headers (GMimeParser *parser)
 	
  content_start:
 	
-	if (priv->headers_end == -1)
-		priv->headers_end = parser_offset (priv, start);
-	
 	priv->state = GMIME_PARSER_STATE_CONTENT;
 	*priv->rawptr = '\0';
 	priv->inptr = start;
@@ -1101,16 +1076,12 @@ parser_step (GMimeParser *parser)
 	case GMIME_PARSER_STATE_ERROR:
 		break;
 	case GMIME_PARSER_STATE_INIT:
-		parser->priv->headers_begin = -1;
-		parser->priv->headers_end = -1;
 		if (priv->scan_from)
 			priv->state = GMIME_PARSER_STATE_FROM;
 		else
 			priv->state = GMIME_PARSER_STATE_HEADERS;
 		break;
 	case GMIME_PARSER_STATE_FROM:
-		parser->priv->headers_begin = -1;
-		parser->priv->headers_end = -1;
 		parser_step_from (parser);
 		break;
 	case GMIME_PARSER_STATE_HEADERS:
@@ -1154,7 +1125,7 @@ enum {
 static int
 check_boundary (struct _GMimeParserPrivate *priv, const char *start, size_t len)
 {
-	off_t offset = parser_offset (priv, start);
+	gint64 offset = parser_offset (priv, start);
 	
 	if (start[len - 1] == '\r')
 		len--;
@@ -1296,11 +1267,11 @@ static void
 parser_scan_mime_part_content (GMimeParser *parser, GMimePart *mime_part, int *found)
 {
 	struct _GMimeParserPrivate *priv = parser->priv;
-	GMimePartEncodingType encoding;
+	GMimeContentEncoding encoding;
 	GByteArray *content = NULL;
 	GMimeDataWrapper *wrapper;
 	GMimeStream *stream;
-	off_t start, end;
+	gint64 start, end;
 	int crlf;
 	
 	g_assert (priv->state >= GMIME_PARSER_STATE_HEADERS_END);
@@ -1323,7 +1294,7 @@ parser_scan_mime_part_content (GMimeParser *parser, GMimePart *mime_part, int *f
 		end = parser_offset (priv, NULL);
 	}
 	
-	encoding = g_mime_part_get_encoding (mime_part);
+	encoding = g_mime_part_get_content_encoding (mime_part);
 	
 	if (priv->persist_stream && priv->seekable)
 		stream = g_mime_stream_substream (priv->stream, start, end);
@@ -1751,7 +1722,7 @@ g_mime_parser_get_from (GMimeParser *parser)
  * Returns the offset of the most recently parsed mbox-style From-line
  * or -1 on error.
  **/
-off_t
+gint64
 g_mime_parser_get_from_offset (GMimeParser *parser)
 {
 	struct _GMimeParserPrivate *priv;
@@ -1764,45 +1735,3 @@ g_mime_parser_get_from_offset (GMimeParser *parser)
 	
 	return priv->from_offset;
 }
-
-
-/**
- * g_mime_parser_get_headers_begin:
- * @parser: a #GMimeParser context
- *
- * Gets the stream offset of the beginning of the headers of the most
- * recently parsed message.
- *
- * Returns: the offset of the beginning of the headers of the most
- * recently parsed message or %-1 on error.
- *
- * Since: 2.2.23
- **/
-off_t
-g_mime_parser_get_headers_begin (GMimeParser *parser)
-{
-	g_return_val_if_fail (GMIME_IS_PARSER (parser), -1);
-	
-	return parser->priv->headers_begin;
-}
-
-
-/**
- * g_mime_parser_get_headers_end:
- * @parser: a #GMimeParser context
- *
- * Gets the stream offset of the end of the headers of the most
- * recently parsed message.
- *
- * Returns: the offset of the end of the headers of the most recently
- * parsed message or %-1 on error.
- *
- * Since: 2.2.23
- **/
-off_t
-g_mime_parser_get_headers_end (GMimeParser *parser)
-{
-	g_return_val_if_fail (GMIME_IS_PARSER (parser), -1);
-	
-	return parser->priv->headers_end;
-}
