@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -85,19 +85,19 @@ print_mime_struct (GMimeStream *stream, GMimeObject *part, int depth)
 
 
 static void
-header_cb (GMimeParser *parser, const char *header, const char *value, off_t offset, gpointer user_data)
+header_cb (GMimeParser *parser, const char *header, const char *value, gint64 offset, gpointer user_data)
 {
 	GMimeStream *stream = user_data;
 	
-	g_mime_stream_printf (stream, OFF_T ": %s: %s\n", offset, header, value);
+	g_mime_stream_printf (stream, "%lld: %s: %s\n", offset, header, value);
 }
 
 static void
 test_parser (GMimeParser *parser, GMimeStream *mbox, GMimeStream *summary)
 {
-	off_t headers_begin, headers_end, start, end;
 	GMimeMessage *message;
 	const char *exev;
+	gint64 start, end;
 	int nmsg = 0;
 	char *from;
 	
@@ -108,12 +108,7 @@ test_parser (GMimeParser *parser, GMimeStream *mbox, GMimeStream *summary)
 		
 		end = g_mime_parser_tell (parser);
 		
-		headers_begin = g_mime_parser_get_headers_begin (parser);
-		headers_end = g_mime_parser_get_headers_end (parser);
-		
-		g_mime_stream_printf (summary, "message offsets: " OFF_T ", " OFF_T "\n", start, end);
-		g_mime_stream_printf (summary, "header offsets: " OFF_T ", " OFF_T "\n",
-				      headers_begin, headers_end);
+		g_mime_stream_printf (summary, "message offsets: %lld, %lld\n", start, end);
 		
 		from = g_mime_parser_get_from (parser);
 		g_mime_stream_printf (summary, "%s\n", from);
@@ -139,7 +134,7 @@ streams_match (GMimeStream *istream, GMimeStream *ostream)
 	char buf[4096], dbuf[4096], errstr[1024], *bufptr, *bufend, *dbufptr;
 	size_t totalsize, totalread = 0;
 	size_t nread, size;
-	off_t offset = 0;
+	gint64 offset = 0;
 	ssize_t n;
 	
 	v(fprintf (stdout, "Checking if streams match... "));
@@ -168,7 +163,7 @@ streams_match (GMimeStream *istream, GMimeStream *ostream)
 		
 		do {
 			if ((n = g_mime_stream_read (ostream, dbuf + nread, size - nread)) <= 0) {
-				fprintf (stderr, "ostream's read() returned " SSIZE_T ", EOF\n", n);
+				fprintf (stderr, "ostream's read(%p, dbuf + " SIZE_T ", " SIZE_T ") returned " SSIZE_T ", EOF\n", ostream, nread, size - nread, n);
 				break;
 			}
 			d(fprintf (stderr, "read " SSIZE_T " bytes from ostream\n", n));
@@ -194,7 +189,7 @@ streams_match (GMimeStream *istream, GMimeStream *ostream)
 		}
 		
 		if (bufptr < bufend) {
-			sprintf (errstr, "Error: content does not match at offset " OFF_T "\n",
+			sprintf (errstr, "Error: content does not match at offset %lld\n",
 				 offset + (bufptr - buf));
 			/*fprintf (stderr, "-->'%.*s'<--\nvs\n-->'%.*s'<--\n",
 			  bufend - bufptr, bufptr, bufend - bufptr, dbufptr);*/
